raw

package
v0.0.0-...-a78d3b8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 14, 2026 License: AGPL-3.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

const (
	VersionMajorMin = 2

	VersionMajor = 2
	VersionMinor = 2
)

Variables

var ErrInvalidParameter = fmt.Errorf("invalid parameter")

Functions

func Close

func Close(handle windows.Handle) error

func GetParam

func GetParam(handle windows.Handle, param types.Param) (uint64, error)

func NewOverlapped

func NewOverlapped() (*windows.Overlapped, error)

func Open

func Open(filter string, layer types.Layer, priority int16, flags types.Flag) (windows.Handle, error)

func OpenWithName

func OpenWithName(name string, filter string, layer types.Layer, priority int16, flags types.Flag) (windows.Handle, error)

OpenWithName open a custom driver with given name use sys.LoadDriver if you want to install you own driver before call this function

func Recv

func Recv(handle windows.Handle, buffer []byte, address *types.Address, overlapped *windows.Overlapped) (uint32, error)

Recv receive packet and address from driver, buffer and address MUST be provided, can't be nil

func Send

func Send(handle windows.Handle, buffer []byte, address *types.Address, overlapped *windows.Overlapped) (uint32, error)

Send inject packet into kernel buffer and address MUST be provided, can't be nil

func SetParam

func SetParam(handle windows.Handle, param types.Param, value uint64) error

func Shutdown

func Shutdown(handle windows.Handle, how types.Shutdown) error

Types

This section is empty.

Jump to